#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-1AhHSoAYNbI4G5OWKCjCxu
key:                  auto-update-0.1.6-1AhHSoAYNbI4G5OWKCjCxu
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  13eb33fbdf69fe96fbf1914d340fff80
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/auto-update-0.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-auto-update
hs-libraries:         HSauto-update-0.1.6-1AhHSoAYNbI4G5OWKCjCxu
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

